@@ -72,8 +72,7 @@ class AutoDocProcessor(BlockProcessor):
         Arguments:
             parser: A `markdown.blockparser.BlockParser` instance.
             md: A `markdown.Markdown` instance.
-            config: The [configuration][mkdocstrings.plugin.MkdocstringsPlugin.config_scheme]
-                of the `mkdocstrings` plugin.
+            config: The [configuration][mkdocstrings.plugin.PluginConfig] of the `mkdocstrings` plugin.
             handlers: The handlers container.
             autorefs: The autorefs plugin instance.
         """
@@ -231,17 +230,23 @@ class AutoDocProcessor(BlockProcessor):
 
 class _PostProcessor(Treeprocessor):
     def run(self, root: Element) -> None:
+        self._remove_duplicated_headings(root)
+
+    def _remove_duplicated_headings(self, parent: Element) -> None:
         carry_text = ""
-        for el in reversed(root):  # Reversed mainly for the ability to mutate during iteration.
+        for el in reversed(parent):  # Reversed mainly for the ability to mutate during iteration.
             if el.tag == "div" and el.get("class") == "mkdocstrings":
                 # Delete the duplicated headings along with their container, but keep the text (i.e. the actual HTML).
                 carry_text = (el.text or "") + carry_text
-                root.remove(el)
-            elif carry_text:
-                el.tail = (el.tail or "") + carry_text
-                carry_text = ""
+                parent.remove(el)
+            else:
+                if carry_text:
+                    el.tail = (el.tail or "") + carry_text
+                    carry_text = ""
+                self._remove_duplicated_headings(el)
+
         if carry_text:
-            root.text = (root.text or "") + carry_text
+            parent.text = (parent.text or "") + carry_text
 
 
 class MkdocstringsExtension(Extension):
