@@ -20,7 +20,7 @@ class InventoryItem:
         domain: str,
         role: str,
         uri: str,
-        priority: str = "1",
+        priority: int = 1,
         dispname: str | None = None,
     ):
         """Initialize the object.
@@ -30,14 +30,14 @@ class InventoryItem:
             domain: The item domain, like 'python' or 'crystal'.
             role: The item role, like 'class' or 'method'.
             uri: The item URI.
-            priority: The item priority. It can help for inventory suggestions.
+            priority: The item priority. Only used internally by mkdocstrings and Sphinx.
             dispname: The item display name.
         """
         self.name: str = name
         self.domain: str = domain
         self.role: str = role
         self.uri: str = uri
-        self.priority: str = priority
+        self.priority: int = priority
         self.dispname: str = dispname or name
 
     def format_sphinx(self) -> str:
@@ -67,7 +67,7 @@ class InventoryItem:
             uri = uri[:-1] + name
         if dispname == "-":
             dispname = name
-        return cls(name, domain, role, uri, priority, dispname)
+        return cls(name, domain, role, uri, int(priority), dispname)
 
 
 class Inventory(dict):
@@ -88,15 +88,33 @@ class Inventory(dict):
         self.project = project
         self.version = version
 
-    def register(self, *args: str, **kwargs: str) -> None:
+    def register(
+        self,
+        name: str,
+        domain: str,
+        role: str,
+        uri: str,
+        priority: int = 1,
+        dispname: str | None = None,
+    ) -> None:
         """Create and register an item.
 
         Arguments:
-            *args: Arguments passed to [InventoryItem][mkdocstrings.inventory.InventoryItem].
-            **kwargs: Keyword arguments passed to [InventoryItem][mkdocstrings.inventory.InventoryItem].
+            name: The item name.
+            domain: The item domain, like 'python' or 'crystal'.
+            role: The item role, like 'class' or 'method'.
+            uri: The item URI.
+            priority: The item priority. Only used internally by mkdocstrings and Sphinx.
+            dispname: The item display name.
         """
-        item = InventoryItem(*args, **kwargs)
-        self[item.name] = item
+        self[name] = InventoryItem(
+            name=name,
+            domain=domain,
+            role=role,
+            uri=uri,
+            priority=priority,
+            dispname=dispname,
+        )
 
     def format_sphinx(self) -> bytes:
         """Format this inventory as a Sphinx `objects.inv` file.
@@ -117,7 +135,10 @@ class Inventory(dict):
             .encode("utf8")
         )
 
-        lines = [item.format_sphinx().encode("utf8") for item in self.values()]
+        lines = [
+            item.format_sphinx().encode("utf8")
+            for item in sorted(self.values(), key=lambda item: (item.domain, item.name))
+        ]
         return header + zlib.compress(b"\n".join(lines) + b"\n", 9)
 
     @classmethod
@@ -129,7 +150,7 @@ class Inventory(dict):
             domain_filter: A collection of domain values to allow (and filter out all other ones).
 
         Returns:
-            An `Inventory` containing the collected `InventoryItem`s.
+            An inventory containing the collected items.
         """
         for _ in range(4):
             in_file.readline()
