@@ -7,24 +7,24 @@ from typing import TYPE_CHECKING, Any, Iterator
 
 import pytest
 from markdown.core import Markdown
-from mkdocs import config
-from mkdocs.config.defaults import get_schema
+from mkdocs.config.defaults import MkDocsConfig
 
 if TYPE_CHECKING:
     from pathlib import Path
 
+    from mkdocs import config
+
     from mkdocstrings.plugin import MkdocstringsPlugin
 
 
 @pytest.fixture(name="mkdocs_conf")
 def fixture_mkdocs_conf(request: pytest.FixtureRequest, tmp_path: Path) -> Iterator[config.Config]:
     """Yield a MkDocs configuration object."""
-    conf = config.Config(schema=get_schema())  # type: ignore[call-arg]
+    conf = MkDocsConfig()
     while hasattr(request, "_parent_request") and hasattr(request._parent_request, "_parent_request"):
         request = request._parent_request
 
     conf_dict = {
-        "config_file_path": "mkdocs_tests.yml",
         "site_name": "foo",
         "site_url": "https://example.org/",
         "site_dir": str(tmp_path),
@@ -53,6 +53,6 @@ def fixture_plugin(mkdocs_conf: config.Config) -> MkdocstringsPlugin:
 
 
 @pytest.fixture(name="ext_markdown")
-def fixture_ext_markdown(mkdocs_conf: config.Config) -> Markdown:
+def fixture_ext_markdown(mkdocs_conf: MkDocsConfig) -> Markdown:
     """Return a Markdown instance with MkdocstringsExtension."""
     return Markdown(extensions=mkdocs_conf["markdown_extensions"], extension_configs=mkdocs_conf["mdx_configs"])
