@@ -140,7 +140,7 @@ def test_dont_register_every_identifier_as_anchor(plugin: MkdocstringsPlugin, ex
     ids = ("id1", "id2", "id3")
     handler.get_anchors = lambda _: ids  # type: ignore[method-assign]
     ext_markdown.convert("::: tests.fixtures.headings")
-    autorefs = ext_markdown.parser.blockprocessors["mkdocstrings"]._autorefs
+    autorefs = ext_markdown.parser.blockprocessors["mkdocstrings"]._autorefs  # type: ignore[attr-defined]
     for identifier in ids:
         assert identifier not in autorefs._url_map
         assert identifier not in autorefs._abs_url_map
@@ -150,3 +150,25 @@ def test_use_options_yaml_key(ext_markdown: Markdown) -> None:
     """Check that using the 'options' YAML key works as expected."""
     assert "h1" in ext_markdown.convert("::: tests.fixtures.headings\n    options:\n      heading_level: 1")
     assert "h1" not in ext_markdown.convert("::: tests.fixtures.headings\n    options:\n      heading_level: 2")
+
+
+@pytest.mark.parametrize("ext_markdown", [{"markdown_extensions": [{"admonition": {}}]}], indirect=["ext_markdown"])
+def test_removing_duplicated_headings(ext_markdown: Markdown) -> None:
+    """Assert duplicated headings are removed from the output."""
+    output = ext_markdown.convert(
+        dedent(
+            """
+            ::: tests.fixtures.headings_many.heading_1
+
+            !!! note
+
+                ::: tests.fixtures.headings_many.heading_2
+
+            ::: tests.fixtures.headings_many.heading_3
+            """,
+        ),
+    )
+    assert output.count(">Heading one<") == 1
+    assert output.count(">Heading two<") == 1
+    assert output.count(">Heading three<") == 1
+    assert output.count('class="mkdocstrings') == 0
